@@ -106,7 +106,6 @@ def notify(start_date, stop_date):
 @cmd.command()
 def reconciled():
     """compare les clients fupe dans aiguillier et api-fup"""
-    click.echo('recupère clients fupé sur aiguillier')
     dataset_reconcile = tablib.Dataset()
     message = ''
     customers = []
@@ -129,7 +128,6 @@ def reconciled():
                             for info in infos
                             if info['name']
                             ]
-    click.echo('verifie si clients fupé dans api-fup')
     url = core.database_url(**FUPDB_CREDENTIALS)
     with records.Database(url) as db:
         sql = (
