@@ -575,6 +575,7 @@ class Customer(object):
         return cdrs_by_policies
 
     def get_cdr_summary(self, start=None, stop=None, daily_details=False):
+        sources = ['cache', 'national', 'internet']
         if not start:
             start = (datetime.now() - timedelta(30))
         if not stop:
@@ -631,9 +632,24 @@ class Customer(object):
                 #  - i['details'] est de longueur 1
                 #  - i['sources'] et i['details'][0]['details'] sont pareils
                 details = i['details'][0]['details']
+                details_sources = []
+                if details:
+                    details_sources = [
+                        x['source'] for x in details
+                    ]
                 del i['details']
                 del i['sources']
                 if daily_details:
+                    for x in sources:
+                        if x not in details_sources:
+                            details.append(
+                                {
+                                    'source': x,
+                                    'octets_in': 0.0,
+                                    'total': 0.0,
+                                    'octets_out': 0.0
+                                }
+                            )
                     i['details'] = details
                 info['policy_wise'].append(i)
             infos['consumption']['details'].append(info)
